@@ -1,4 +1,4 @@
-__version__ = '0.2.4'
+__version__ = '0.2.5'
 import struct
 import binascii
 
@@ -19,12 +19,12 @@ def read_all(filename='data.bin'):
     f = open(filename, 'rb')
     output = []
     Is = 'B'*num_bytes
-    Ds = 'd'*512
-    vec_len = 512*8
+    Fs = 'f'*512
+    vec_len = 512*4
     while True:
         try:
             tmp = [binascii.hexlify(bytearray(struct.unpack(Is, f.read(16)))),
-                   struct.unpack(Ds, f.read(vec_len))]
+                   struct.unpack(Fs, f.read(vec_len))]
             output.append(tmp)
         except:
             break
